BATS is proud to be San Francisco’s premier home for improvised theatre.
We've been innovating improv for over 30 years! We have shows every Friday and
Saturday at 8pm at our theatre in Fort Mason Center (right across from The
Interval's delicious craft cocktails, coffee & tea). Come on a Friday for one
of our fast-paced, variety-packed shortform shows. Or come on a Saturday for
one of our world-famous genre longform shows. Either way, you’re sure to
experience the unique blend of theatre and comedy that is BATS Improv. We also
offer classes at all levels for individuals, and customized corporate training
and experiences through our Improv @ Work program.

Visit us online https://improv.org

Get in touch bats@improv.org

If you find this software useful, please consider making a tax-deductible
donation to BATS Improv (it's quick and easy)!

https://improv.org/support-bats

The activecampaign3 package integrates with Active Campaign's Version 3 API.

http://developers.activecampaign.com/

ALPHA SOFTWARE in early development. See tests for usage examples.

Copy config-example.yml to config.yml and provide your API url and key.

TESTS ARE DESTRUCTIVE DO NOT RUN ON YOUR REAL ACCOUNT

Licensed under the 3-clause BSD, see LICENSE.txt
